pub struct Message {
pub from_party_id: String,
pub to_party_id: Option<String>,
pub round: u8,
pub payload: Vec<u8>,
}Expand description
A single inter-party message belonging to one round of a session.
from_party_id and to_party_id are the canonical ASCII party ids
from crate::party::Party. to_party_id == None means broadcast
— every other party should process this message. round is the
1-indexed round number the message belongs to; payload is the
scheme-specific wire bytes (commitments, signature shares, etc.).
Fields
from_party_id: Stringto_party_id: Option<String>round: u8payload: Vec<u8>Implementations
Sourceimpl Message
impl Message
Sourcepub fn directed(
from: impl Into<String>,
to: impl Into<String>,
round: u8,
payload: impl Into<Vec<u8>>,
) -> Self
pub fn directed( from: impl Into<String>, to: impl Into<String>, round: u8, payload: impl Into<Vec<u8>>, ) -> Self
Build a directed (point-to-point) message.
Sourcepub fn broadcast(
from: impl Into<String>,
round: u8,
payload: impl Into<Vec<u8>>,
) -> Self
pub fn broadcast( from: impl Into<String>, round: u8, payload: impl Into<Vec<u8>>, ) -> Self
Build a broadcast message — addressed to every other party.
Sourcepub fn is_broadcast(&self) -> bool
pub fn is_broadcast(&self) -> bool
True when this message is addressed to every party.
Sourcepub fn is_directed(&self) -> bool
pub fn is_directed(&self) -> bool
True when this message is directed at exactly one party.